from fastapi import APIRouter, Depends, Security
from sqlalchemy.orm import Session

from ..core.security import get_current_active_user as get_user
from ..db.session import SessionLocal
from ..models.db_setting import DbSetting
from ..schemas.settings import PrefillCustomerDiscount
from ..schemas.user_token import UserToken


router = APIRouter()


# Dependency
def get_db() -> Session:
    try:
        db = SessionLocal()
        yield db
    finally:
        db.close()


@router.get("/prefill-customer-discount", response_model=PrefillCustomerDiscount)
def get_prefill_customer_discount(
    db: Session = Depends(get_db),
    user: UserToken = Security(get_user),
) -> PrefillCustomerDiscount:
    value = db.query(DbSetting).filter(DbSetting.name == "Prefill Customer Discount").first().data["Value"]
    return PrefillCustomerDiscount(value=value)


@router.post("/prefill-customer-discount", response_model=PrefillCustomerDiscount)
def set_prefill_customer_discount(
    data: PrefillCustomerDiscount,
    db: Session = Depends(get_db),
    user: UserToken = Security(get_user, scopes=["settings"]),
) -> PrefillCustomerDiscount:
    item = db.query(DbSetting).filter(DbSetting.name == "Prefill Customer Discount").first()
    item.data = {"Value": data.value}
    db.commit()
    return PrefillCustomerDiscount(value=item.data["Value"])
